"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.upgradeableTooling = void 0;
const tslib_1 = require("tslib");
const adoptium_java_1 = require("../../datasource/adoptium-java");
const docker_1 = require("../../datasource/docker");
const github_releases_1 = require("../../datasource/github-releases");
const github_tags_1 = require("../../datasource/github-tags");
const node_1 = require("../../datasource/node");
const ruby_version_1 = require("../../datasource/ruby-version");
const nodeVersioning = tslib_1.__importStar(require("../../versioning/node"));
const regexVersioning = tslib_1.__importStar(require("../../versioning/regex"));
const semverVersioning = tslib_1.__importStar(require("../../versioning/semver"));
exports.upgradeableTooling = {
    awscli: {
        datasource: github_tags_1.GithubTagsDatasource.id,
        packageName: 'aws/aws-cli',
        versioning: semverVersioning.id,
    },
    bun: {
        datasource: github_releases_1.GithubReleasesDatasource.id,
        packageName: 'oven-sh/bun',
        versioning: semverVersioning.id,
        extractVersion: '^bun-v(?<version>\\S+)',
    },
    'cargo-make': {
        datasource: github_releases_1.GithubReleasesDatasource.id,
        packageName: 'sagiegurari/cargo-make',
        versioning: semverVersioning.id,
    },
    clojure: {
        datasource: github_tags_1.GithubTagsDatasource.id,
        packageName: 'clojure/brew-install',
        versioning: `${regexVersioning.id}:^(?<major>\\d+?)\\.(?<minor>\\d+?)\\.(?<patch>\\d+)\\.(?<build>\\d+)$`,
    },
    crystal: {
        datasource: github_releases_1.GithubReleasesDatasource.id,
        packageName: 'crystal-lang/crystal',
        versioning: semverVersioning.id,
    },
    deno: {
        datasource: github_releases_1.GithubReleasesDatasource.id,
        packageName: 'denoland/deno',
        versioning: semverVersioning.id,
        extractVersion: '^v(?<version>\\S+)',
    },
    direnv: {
        datasource: github_releases_1.GithubReleasesDatasource.id,
        packageName: 'direnv/direnv',
        versioning: semverVersioning.id,
        extractVersion: '^v(?<version>\\S+)',
    },
    dprint: {
        datasource: github_releases_1.GithubReleasesDatasource.id,
        packageName: 'dprint/dprint',
        versioning: semverVersioning.id,
    },
    elixir: {
        datasource: github_tags_1.GithubTagsDatasource.id,
        packageName: 'elixir-lang/elixir',
        versioning: semverVersioning.id,
        extractVersion: '^v(?<version>\\S+)',
    },
    elm: {
        datasource: github_releases_1.GithubReleasesDatasource.id,
        packageName: 'elm/compiler',
        versioning: semverVersioning.id,
    },
    erlang: {
        datasource: github_tags_1.GithubTagsDatasource.id,
        packageName: 'erlang/otp',
        extractVersion: '^OTP-(?<version>\\S+)',
        versioning: `${regexVersioning.id}:^(?<major>\\d+?)\\.(?<minor>\\d+?)(\\.(?<patch>\\d+))?$`,
    },
    gauche: {
        datasource: docker_1.DockerDatasource.id,
        packageName: 'practicalscheme/gauche',
        versioning: semverVersioning.id,
    },
    golang: {
        datasource: github_tags_1.GithubTagsDatasource.id,
        packageName: 'golang/go',
        versioning: semverVersioning.id,
        extractVersion: '^go(?<version>\\S+)',
    },
    haskell: {
        datasource: github_tags_1.GithubTagsDatasource.id,
        packageName: 'ghc/ghc',
        versioning: semverVersioning.id,
        extractVersion: '^ghc-(?<version>\\S+?)-release',
    },
    helm: {
        datasource: github_releases_1.GithubReleasesDatasource.id,
        packageName: 'helm/helm',
        versioning: semverVersioning.id,
        extractVersion: '^v(?<version>\\S+)',
    },
    helmfile: {
        datasource: github_releases_1.GithubReleasesDatasource.id,
        packageName: 'helmfile/helmfile',
        versioning: semverVersioning.id,
        extractVersion: '^v(?<version>\\S+)',
    },
    hugo: {
        datasource: github_releases_1.GithubReleasesDatasource.id,
        packageName: 'gohugoio/hugo',
        versioning: semverVersioning.id,
        extractVersion: '^v(?<version>\\S+)',
    },
    idris: {
        datasource: github_tags_1.GithubTagsDatasource.id,
        packageName: 'idris-lang/Idris-dev',
        versioning: semverVersioning.id,
        extractVersion: '^v(?<version>\\S+)',
    },
    java: (version) => {
        const adoptOpenJdkMatches = version.match(/^adoptopenjdk-(?<version>\d\S+)/);
        if (adoptOpenJdkMatches) {
            return {
                datasource: adoptium_java_1.AdoptiumJavaDatasource.id,
                packageName: 'java-jdk',
                versioning: semverVersioning.id,
                currentValue: adoptOpenJdkMatches.groups.version,
            };
        }
        const adoptOpenJreMatches = version.match(/^adoptopenjdk-jre-(?<version>\d\S+)/);
        if (adoptOpenJreMatches) {
            return {
                datasource: adoptium_java_1.AdoptiumJavaDatasource.id,
                packageName: 'java-jre',
                versioning: semverVersioning.id,
                currentValue: adoptOpenJreMatches.groups.version,
            };
        }
        return undefined;
    },
    julia: {
        datasource: github_releases_1.GithubReleasesDatasource.id,
        packageName: 'JuliaLang/julia',
        versioning: semverVersioning.id,
        extractVersion: '^v(?<version>\\S+)',
    },
    just: {
        datasource: github_releases_1.GithubReleasesDatasource.id,
        packageName: 'casey/just',
        versioning: semverVersioning.id,
    },
    kotlin: {
        datasource: github_releases_1.GithubReleasesDatasource.id,
        packageName: 'JetBrains/kotlin',
        versioning: semverVersioning.id,
        extractVersion: '^(Kotlin |v)(?<version>\\S+)',
    },
    kustomize: {
        datasource: github_releases_1.GithubReleasesDatasource.id,
        packageName: 'kubernetes-sigs/kustomize',
        versioning: semverVersioning.id,
        extractVersion: '^kustomize/v(?<version>\\S+)',
    },
    lua: {
        datasource: github_releases_1.GithubReleasesDatasource.id,
        packageName: 'lua/lua',
        versioning: semverVersioning.id,
        extractVersion: '^v(?<version>\\S+)',
    },
    nim: {
        datasource: github_tags_1.GithubTagsDatasource.id,
        packageName: 'nim-lang/Nim',
        versioning: semverVersioning.id,
        extractVersion: '^v(?<version>\\S+)',
    },
    nodejs: {
        depName: 'node',
        datasource: node_1.NodeDatasource.id,
        packageName: 'node',
        versioning: nodeVersioning.id,
    },
    ocaml: {
        datasource: github_releases_1.GithubReleasesDatasource.id,
        packageName: 'ocaml/ocaml',
        versioning: semverVersioning.id,
    },
    perl: {
        datasource: github_tags_1.GithubTagsDatasource.id,
        packageName: 'Perl/perl5',
        versioning: semverVersioning.id,
        extractVersion: '^v(?<version>\\S+)',
    },
    php: {
        datasource: github_tags_1.GithubTagsDatasource.id,
        packageName: 'php/php-src',
        versioning: semverVersioning.id,
        extractVersion: '^php-(?<version>\\S+)',
    },
    python: {
        datasource: github_tags_1.GithubTagsDatasource.id,
        packageName: 'python/cpython',
        versioning: semverVersioning.id,
        extractVersion: '^v(?<version>\\S+)',
    },
    ruby: {
        datasource: ruby_version_1.RubyVersionDatasource.id,
        packageName: 'ruby-version',
        versioning: semverVersioning.id,
    },
    rust: {
        datasource: github_tags_1.GithubTagsDatasource.id,
        packageName: 'rust-lang/rust',
        versioning: semverVersioning.id,
    },
    scala: (version) => {
        if (version.startsWith('2')) {
            return {
                datasource: github_tags_1.GithubTagsDatasource.id,
                packageName: 'scala/scala',
                versioning: semverVersioning.id,
                extractVersion: '^v(?<version>\\S+)',
            };
        }
        if (version.startsWith('3')) {
            return {
                datasource: github_tags_1.GithubTagsDatasource.id,
                packageName: 'lampepfl/dotty',
                versioning: semverVersioning.id,
            };
        }
        return undefined;
    },
    shellcheck: {
        datasource: github_releases_1.GithubReleasesDatasource.id,
        packageName: 'koalaman/shellcheck',
        versioning: semverVersioning.id,
        extractVersion: '^v(?<version>\\S+)',
    },
    shfmt: {
        datasource: github_releases_1.GithubReleasesDatasource.id,
        packageName: 'mvdan/sh',
        versioning: semverVersioning.id,
        extractVersion: '^v(?<version>\\S+)',
    },
    terraform: {
        datasource: github_releases_1.GithubReleasesDatasource.id,
        packageName: 'hashicorp/terraform',
        versioning: semverVersioning.id,
        extractVersion: '^v(?<version>\\S+)',
    },
    trivy: {
        datasource: github_releases_1.GithubReleasesDatasource.id,
        packageName: 'aquasecurity/trivy',
        versioning: semverVersioning.id,
        extractVersion: '^v(?<version>\\S+)',
    },
    zig: {
        datasource: github_tags_1.GithubTagsDatasource.id,
        packageName: 'ziglang/zig',
        versioning: semverVersioning.id,
    },
};
//# sourceMappingURL=upgradeable-tooling.js.map